@@ -58,7 +58,7 @@ bool closeDocs(const QList<KTextEditor::Document *> &docs)
 class CloseIconStyleDelegate : public QStyledItemDelegate
 {
 public:
-    CloseIconStyleDelegate(QObject *parent = nullptr)
+    explicit CloseIconStyleDelegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
     {
     }
@@ -784,3 +784,5 @@ void KateFileTree::slotDocumentDelete()
 }
 
 // END KateFileTree
+
+#include "moc_katefiletree.cpp"
