@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KATE_FILETREE_H
-#define KATE_FILETREE_H
+#pragma once
 
 #include <QIcon>
 #include <QTreeView>
@@ -14,6 +13,7 @@
 namespace KTextEditor
 {
 class Document;
+class MainWindow;
 }
 
 class QActionGroup;
@@ -26,7 +26,7 @@ class KateFileTree : public QTreeView
     Q_OBJECT
 
 public:
-    KateFileTree(QWidget *parent);
+    KateFileTree(KTextEditor::MainWindow *mainWindow, QWidget *parent);
     ~KateFileTree() override;
 
     void setModel(QAbstractItemModel *model) override;
@@ -121,6 +121,6 @@ private:
     QPersistentModelIndex m_indexContextMenu;
 
     bool m_hasCloseButton = false;
-};
 
-#endif // KATE_FILETREE_H
+    KTextEditor::MainWindow *m_mainWindow;
+};
