@@ -9,6 +9,7 @@
 #include "backend.h"
 #include "debugview.h"
 #include "debugview_dap.h"
+#include <KLocalizedString>
 #include <KMessageBox>
 
 Backend::Backend(QObject *parent)
@@ -32,7 +33,7 @@ void Backend::runDebugger(const GDBTargetConf &conf, const QStringList &ioFifos)
         m_mode = GDB;
         bind();
     } else {
-        gdb = dynamic_cast<DebugView *>(m_debugger);
+        gdb = qobject_cast<DebugView *>(m_debugger);
     }
 
     gdb->runDebugger(conf, ioFifos);
@@ -252,3 +253,5 @@ void Backend::changeScope(int scopeId)
     if (m_debugger)
         m_debugger->changeScope(scopeId);
 }
+
+#include "moc_backend.cpp"
