@@ -7,8 +7,10 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QJsonDocument>
+#include <QRegularExpression>
 #include <pthread.h>
-#include <qregularexpression.h>
+
+#include <KLocalizedString>
 
 #include "debugview_dap.h"
 #include "json_placeholders.h"
@@ -1731,3 +1733,5 @@ QString DapDebugView::resolveOrWarn(const QString &filename)
 
     return filename;
 }
+
+#include "moc_debugview_dap.cpp"
