@@ -41,6 +41,21 @@ public:
     ~KatePluginGDB() override;
 
     QObject *createView(KTextEditor::MainWindow *mainWindow) override;
+    int configPages() const override;
+    KTextEditor::ConfigPage *configPage(int number = 0, QWidget *parent = nullptr) override;
+    void readConfig();
+    void writeConfig() const;
+
+    const QString m_settingsPath;
+    const QUrl m_defaultConfigPath;
+    QUrl m_configPath;
+    QUrl configPath() const
+    {
+        return m_configPath.isEmpty() ? m_defaultConfigPath : m_configPath;
+    }
+Q_SIGNALS:
+    // Update for config
+    void update() const;
 };
 
 class KatePluginGDBView : public QObject, public KXMLGUIClient, public KTextEditor::SessionConfigInterface
@@ -49,7 +64,7 @@ class KatePluginGDBView : public QObject, public KXMLGUIClient, public KTextEdit
     Q_INTERFACES(KTextEditor::SessionConfigInterface)
 
 public:
-    KatePluginGDBView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mainWin);
+    KatePluginGDBView(KatePluginGDB *plugin, KTextEditor::MainWindow *mainWin);
     ~KatePluginGDBView() override;
 
     // reimplemented: read and write session config
@@ -98,6 +113,7 @@ private:
     QString currentWord();
 
     void displayMessage(const QString &message, KTextEditor::Message::MessageType level);
+    QToolButton *createDebugButton(QAction *action);
 
     KTextEditor::Application *m_kateApplication;
     KTextEditor::MainWindow *m_mainWin;
@@ -123,4 +139,8 @@ private:
     int m_lastExecFrame;
     bool m_focusOnInput;
     QPointer<KTextEditor::Message> m_infoMessage;
+
+    //Debug buttons
+    QWidget *m_buttonWidget;
+    QToolButton *m_continueButton;
 };
