@@ -5,7 +5,6 @@
 */
 #include "gotoglobalsymbolmodel.h"
 
-#include <QFileInfo>
 #include <QIcon>
 
 GotoGlobalSymbolModel::GotoGlobalSymbolModel(QObject *parent)
@@ -67,3 +66,5 @@ QVariant GotoGlobalSymbolModel::data(const QModelIndex &index, int role) const
 
     return QVariant();
 }
+
+#include "moc_gotoglobalsymbolmodel.cpp"
