@@ -21,6 +21,7 @@
 #include <QTextDocument>
 #include <QVBoxLayout>
 
+#include <KTextEditor/Document>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/Message>
 #include <KTextEditor/View>
@@ -28,7 +29,7 @@
 class CtagsGotoSymbolProxyModel : public QSortFilterProxyModel
 {
 public:
-    CtagsGotoSymbolProxyModel(QObject *parent = nullptr)
+    explicit CtagsGotoSymbolProxyModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
     {
     }
@@ -64,7 +65,7 @@ private:
 class GotoStyleDelegate : public QStyledItemDelegate
 {
 public:
-    GotoStyleDelegate(QObject *parent = nullptr)
+    explicit GotoStyleDelegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
     {
     }
@@ -397,3 +398,5 @@ void GotoSymbolWidget::reselectFirst()
         m_treeView->setCurrentIndex(index);
     }
 }
+
+#include "moc_gotosymbolwidget.cpp"
