@@ -21,7 +21,7 @@
 #include <kde_terminal_interface.h>
 
 struct AppOutput::Private {
-    Private(AppOutput *pub)
+    explicit Private(AppOutput *pub)
         : q(pub)
     {
     }
@@ -74,7 +74,12 @@ AppOutput::AppOutput(QWidget *parent)
     : QWidget(parent)
     , d(std::make_unique<AppOutput::Private>(this))
 {
-    KPluginFactory *factory = KPluginFactory::loadFactory(QStringLiteral("konsolepart")).plugin;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const QString konsolePart = QStringLiteral("konsolepart");
+#else
+    const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
+#endif
+    KPluginFactory *factory = KPluginFactory::loadFactory(konsolePart).plugin;
     if (!factory) {
         qDebug() << "could not load the konsolepart factory";
     } else {
@@ -169,3 +174,5 @@ QString AppOutput::runningProcess()
     QString program = d->process.program().isEmpty() ? QString() : d->process.program().first();
     return d->process.state() == QProcess::NotRunning ? QString() : program;
 }
+
+#include "moc_AppOutput.cpp"
