@@ -4,8 +4,7 @@ SPDX-FileCopyrightText: 2010 Marco Mentasti <marcomentasti@gmail.com>
 SPDX-License-Identifier: LGPL-2.0-only
 */
 
-#ifndef CACHEDSQLQUERYMODEL_H
-#define CACHEDSQLQUERYMODEL_H
+#pragma once
 
 #include <QContiguousCache>
 #include <QSqlQueryModel>
@@ -35,5 +34,3 @@ private:
 
     mutable QContiguousCache<QSqlRecord> cache;
 };
-
-#endif // CACHEDSQLQUERYMODEL_H
