@@ -77,7 +77,7 @@ void DataOutputModel::readConfig()
         s->background.setColor(g.readEntry("backgroundColor", s->background.color()));
     }
 
-    emit dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1));
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1));
 }
 
 bool DataOutputModel::useSystemLocale() const
@@ -89,99 +89,132 @@ void DataOutputModel::setUseSystemLocale(bool useSystemLocale)
 {
     m_useSystemLocale = useSystemLocale;
 
-    emit dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1));
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, columnCount() - 1));
 }
 
 QVariant DataOutputModel::data(const QModelIndex &index, int role) const
 {
-    if (role == Qt::EditRole)
+    if (role == Qt::EditRole) {
         return CachedSqlQueryModel::data(index, role);
+    }
 
     const QVariant value(CachedSqlQueryModel::data(index, Qt::DisplayRole));
     const QVariant::Type type = value.type();
 
     if (value.isNull()) {
-        if (role == Qt::FontRole)
+        if (role == Qt::FontRole) {
             return QVariant(m_styles.value(QStringLiteral("null"))->font);
-        if (role == Qt::ForegroundRole)
+        }
+        if (role == Qt::ForegroundRole) {
             return QVariant(m_styles.value(QStringLiteral("null"))->foreground);
-        if (role == Qt::BackgroundRole)
+        }
+        if (role == Qt::BackgroundRole) {
             return QVariant(m_styles.value(QStringLiteral("null"))->background);
-        if (role == Qt::DisplayRole)
+        }
+        if (role == Qt::DisplayRole) {
             return QVariant(QLatin1String("NULL"));
+        }
     }
 
     if (type == QVariant::ByteArray) {
-        if (role == Qt::FontRole)
+        if (role == Qt::FontRole) {
             return QVariant(m_styles.value(QStringLiteral("blob"))->font);
-        if (role == Qt::ForegroundRole)
+        }
+        if (role == Qt::ForegroundRole) {
             return QVariant(m_styles.value(QStringLiteral("blob"))->foreground);
-        if (role == Qt::BackgroundRole)
+        }
+        if (role == Qt::BackgroundRole) {
             return QVariant(m_styles.value(QStringLiteral("blob"))->background);
-        if (role == Qt::DisplayRole)
+        }
+        if (role == Qt::DisplayRole) {
             return QVariant(value.toByteArray().left(255));
+        }
     }
 
     if (isNumeric(type)) {
-        if (role == Qt::FontRole)
+        if (role == Qt::FontRole) {
             return QVariant(m_styles.value(QStringLiteral("number"))->font);
-        if (role == Qt::ForegroundRole)
+        }
+        if (role == Qt::ForegroundRole) {
             return QVariant(m_styles.value(QStringLiteral("number"))->foreground);
-        if (role == Qt::BackgroundRole)
+        }
+        if (role == Qt::BackgroundRole) {
             return QVariant(m_styles.value(QStringLiteral("number"))->background);
-        if (role == Qt::TextAlignmentRole)
+        }
+        if (role == Qt::TextAlignmentRole) {
             return QVariant(Qt::AlignRight | Qt::AlignVCenter);
+        }
         if (role == Qt::DisplayRole || role == Qt::UserRole) {
-            if (useSystemLocale())
+            if (useSystemLocale()) {
                 return QVariant(value.toString()); // FIXME KF5 KGlobal::locale()->formatNumber(value.toString(), false));
-            else
+            } else {
                 return QVariant(value.toString());
+            }
         }
     }
 
     if (type == QVariant::Bool) {
-        if (role == Qt::FontRole)
+        if (role == Qt::FontRole) {
             return QVariant(m_styles.value(QStringLiteral("bool"))->font);
-        if (role == Qt::ForegroundRole)
+        }
+        if (role == Qt::ForegroundRole) {
             return QVariant(m_styles.value(QStringLiteral("bool"))->foreground);
-        if (role == Qt::BackgroundRole)
+        }
+        if (role == Qt::BackgroundRole) {
             return QVariant(m_styles.value(QStringLiteral("bool"))->background);
-        if (role == Qt::DisplayRole)
+        }
+        if (role == Qt::DisplayRole) {
             return QVariant(value.toBool() ? QLatin1String("True") : QLatin1String("False"));
-    }
-
-    if (type == QVariant::Date || type == QVariant::Time || type == QVariant::DateTime) {
-        if (role == Qt::FontRole)
-            return QVariant(m_styles.value(QStringLiteral("datetime"))->font);
-        if (role == Qt::ForegroundRole)
-            return QVariant(m_styles.value(QStringLiteral("datetime"))->foreground);
-        if (role == Qt::BackgroundRole)
-            return QVariant(m_styles.value(QStringLiteral("datetime"))->background);
-        if (role == Qt::DisplayRole || role == Qt::UserRole) {
-            if (useSystemLocale()) {
-                if (type == QVariant::Date)
-                    return QVariant(QLocale().toString(value.toDate(), QLocale::ShortFormat));
-                if (type == QVariant::Time)
-                    return QVariant(QLocale().toString(value.toTime()));
-                if (type == QVariant::DateTime)
-                    return QVariant(QLocale().toString(value.toDateTime(), QLocale::ShortFormat));
-            } else // return sql server format
-                return QVariant(value.toString());
         }
     }
 
-    if (role == Qt::FontRole)
+    if (type == QVariant::Date || type == QVariant::Time || type == QVariant::DateTime) {
+        if (role == Qt::FontRole) {
+            return QVariant(m_styles.value(QStringLiteral("datetime"))->font);
+        }
+        if (role == Qt::ForegroundRole) {
+            return QVariant(m_styles.value(QStringLiteral("datetime"))->foreground);
+        }
+        if (role == Qt::BackgroundRole) {
+            return QVariant(m_styles.value(QStringLiteral("datetime"))->background);
+        }
+        if (role == Qt::DisplayRole || role == Qt::UserRole) {
+            if (useSystemLocale()) {
+                if (type == QVariant::Date) {
+                    return QVariant(QLocale().toString(value.toDate(), QLocale::ShortFormat));
+                }
+                if (type == QVariant::Time) {
+                    return QVariant(QLocale().toString(value.toTime()));
+                }
+                if (type == QVariant::DateTime) {
+                    return QVariant(QLocale().toString(value.toDateTime(), QLocale::ShortFormat));
+                }
+            } else { // return sql server format
+                return QVariant(value.toString());
+            }
+        }
+    }
+
+    if (role == Qt::FontRole) {
         return QVariant(m_styles.value(QStringLiteral("text"))->font);
-    if (role == Qt::ForegroundRole)
+    }
+    if (role == Qt::ForegroundRole) {
         return QVariant(m_styles.value(QStringLiteral("text"))->foreground);
-    if (role == Qt::BackgroundRole)
+    }
+    if (role == Qt::BackgroundRole) {
         return QVariant(m_styles.value(QStringLiteral("text"))->background);
-    if (role == Qt::TextAlignmentRole)
+    }
+    if (role == Qt::TextAlignmentRole) {
         return QVariant(Qt::AlignVCenter);
-    if (role == Qt::DisplayRole)
+    }
+    if (role == Qt::DisplayRole) {
         return value.toString();
-    if (role == Qt::UserRole)
+    }
+    if (role == Qt::UserRole) {
         return value;
+    }
 
     return CachedSqlQueryModel::data(index, role);
 }
+
+#include "moc_dataoutputmodel.cpp"
