@@ -6,8 +6,6 @@
 
 #include "dataoutputview.h"
 
-#include <QAction>
-
 #include <QCursor>
 #include <QMenu>
 
@@ -29,3 +27,5 @@ void DataOutputView::slotCustomContextMenuRequested(const QPoint &pos)
 
     menu.exec(mapToGlobal(pos));
 }
+
+#include "moc_dataoutputview.cpp"
