@@ -10,6 +10,7 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KUrlRequester>
+#include <kio_version.h>
 
 #include <QCheckBox>
 #include <QFormLayout>
@@ -51,7 +52,11 @@ ExportOutputPage::ExportOutputPage(QWidget *parent)
 
     fileUrl = new KUrlRequester(this);
     fileUrl->setMode(KFile::File);
-    fileUrl->setFilter(i18n("*.csv|Comma Separated Values\n*|All files"));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
+    fileUrl->setNameFilters({i18n("Comma Separated Values") + QLatin1String(" (*.csv)"), i18n("All files") + QLatin1String(" (*)")});
+#else
+    fileUrl->setFilter(QLatin1String("*.csv|") + i18n("Comma Separated Values") + QLatin1String("\n*|") + i18n("All files"));
+#endif
 
     fileLayout->addWidget(fileUrl);
 
@@ -186,3 +191,5 @@ bool ExportFormatPage::validatePage()
     return true;
 }
 // END ExportFormatPage
+
+#include "moc_exportwizard.cpp"
