@@ -12,20 +12,18 @@
 
 #include <QDateTime>
 #include <QFontDatabase>
-#include <QLayout>
+#include <QHBoxLayout>
 #include <QLocale>
 #include <QStyle>
 #include <QTextEdit>
 
 TextOutputWidget::TextOutputWidget(QWidget *parent)
     : QWidget(parent)
+    , m_succesTextColor(QColor::fromRgb(3, 191, 3))
+    , m_succesBackgroundColor(QColor::fromRgb(231, 247, 231))
+    , m_errorTextColor(QColor::fromRgb(191, 3, 3))
+    , m_errorBackgroundColor(QColor::fromRgb(247, 231, 231))
 {
-    m_succesTextColor = QColor::fromRgb(3, 191, 3);
-    m_succesBackgroundColor = QColor::fromRgb(231, 247, 231);
-
-    m_errorTextColor = QColor::fromRgb(191, 3, 3);
-    m_errorBackgroundColor = QColor::fromRgb(247, 231, 231);
-
     m_layout = new QHBoxLayout(this);
 
     m_output = new QTextEdit();
@@ -94,3 +92,5 @@ void TextOutputWidget::writeMessage(const QString &msg)
 
     raise();
 }
+
+#include "moc_textoutputwidget.cpp"
