@@ -30,6 +30,7 @@
 #include <QIcon>
 #include <QLabel>
 #include <QLineEdit>
+#include <QPainter>
 #include <QPushButton>
 #include <QShowEvent>
 #include <QStyle>
@@ -37,6 +38,7 @@
 #include <QVBoxLayout>
 
 #include <KAuthorized>
+#include <KColorScheme>
 #include <KConfigGroup>
 #include <KPluginFactory>
 #include <KSharedConfig>
@@ -198,7 +200,13 @@ void KateConsole::loadConsoleIfNeeded()
         /**
          * get konsole part factory
          */
-        KPluginFactory *factory = KPluginFactory::loadFactory(QStringLiteral("konsolepart")).plugin;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        const QString konsolePart = QStringLiteral("konsolepart");
+#else
+        const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
+#endif
+
+        KPluginFactory *factory = KPluginFactory::loadFactory(konsolePart).plugin;
         if (!factory) {
             return;
         }
@@ -283,14 +291,31 @@ void KateConsole::showEvent(QShowEvent *)
     loadConsoleIfNeeded();
 }
 
-static constexpr QChar eolChar()
+void KateConsole::paintEvent(QPaintEvent *e)
+{
+    if (hasKonsole()) {
+        QWidget::paintEvent(e);
+        return;
+    }
+    QPainter p(this);
+    p.setPen(QPen(KColorScheme().foreground(KColorScheme::NegativeText), 1));
+    p.setBrush(Qt::NoBrush);
+    p.drawRect(rect().adjusted(1, 1, -1, -1));
+    auto font = p.font();
+    font.setPixelSize(20);
+    p.setFont(font);
+    const QString text = i18n("Konsole not installed. Please install konsole to be able to use the terminal.");
+    p.drawText(rect(), Qt::AlignCenter | Qt::TextWordWrap, text);
+}
+
+static constexpr QLatin1String eolChar()
 {
     // On windows, if the shell is powershell
     // '\r' needs to be sent to trigger enter
 #ifdef Q_OS_WIN
-    return QLatin1Char('\r');
+    return QLatin1String("\r\n");
 #else
-    return QLatin1Char('\n');
+    return QLatin1String("\n");
 #endif
 }
 
@@ -347,7 +372,13 @@ KPluginFactory *KateConsole::pluginFactory()
     if (s_pluginFactory) {
         return s_pluginFactory;
     }
-    return s_pluginFactory = KPluginFactory::loadFactory(QStringLiteral("konsolepart")).plugin;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const QString konsolePart = QStringLiteral("konsolepart");
+#else
+    const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
+#endif
+
+    return s_pluginFactory = KPluginFactory::loadFactory(konsolePart).plugin;
 }
 
 void KateConsole::slotPipeToConsole()
@@ -549,7 +580,7 @@ void KateConsole::handleEsc(QEvent *e)
             if (m_toolView && m_toolView->isVisible() && !exceptList.contains(app)) {
                 m_mw->hideToolView(m_toolView);
             }
-        } else {
+        } else if (m_toolView && m_toolView->isVisible()) {
             m_mw->hideToolView(m_toolView);
         }
     }
@@ -668,5 +699,6 @@ void KateKonsoleConfigPage::reset()
 }
 
 #include "kateconsole.moc"
+#include "moc_kateconsole.cpp"
 
 // kate: space-indent on; indent-width 4; replace-tabs on;
