@@ -4,8 +4,7 @@
     SPDX-License-Identifier: MIT
 */
 
-#ifndef LSPCLIENTPLUGIN_H
-#define LSPCLIENTPLUGIN_H
+#pragma once
 
 #include <QUrl>
 #include <QVariant>
@@ -49,10 +48,6 @@ public:
     bool m_refDeclaration = false;
     bool m_complParens = false;
     bool m_diagnostics = false;
-    bool m_diagnosticsHighlight = false;
-    bool m_diagnosticsMark = false;
-    bool m_diagnosticsHover = false;
-    unsigned m_diagnosticsSize = 0;
     bool m_messages = false;
     bool m_autoHover = false;
     bool m_onTypeFormatting = false;
@@ -62,6 +57,8 @@ public:
     bool m_semanticHighlighting = false;
     bool m_signatureHelp = true;
     bool m_autoImport = true;
+    bool m_fmtOnSave = false;
+    bool m_inlayHints = false;
 
     // debug mode?
     const bool m_debugMode;
@@ -103,7 +100,5 @@ private Q_SLOTS:
 
 private:
     // server manager to pass along
-    QSharedPointer<LSPClientServerManager> m_serverManager;
+    std::shared_ptr<LSPClientServerManager> m_serverManager;
 };
-
-#endif
