@@ -947,7 +947,12 @@ static QVector<LSPInlayHint> parseInlayHints(const QJsonValue &result)
         h.position = parsePosition(hint[QStringLiteral("position")].toObject());
         h.paddingLeft = hint[QStringLiteral("paddingLeft")].toBool();
         h.paddingRight = hint[QStringLiteral("paddingRight")].toBool();
-        ret.push_back(h);
+        // if the last position and current one is same, merge the labels
+        if (!ret.empty() && ret.back().position == h.position) {
+            ret.back().label += h.label;
+        } else {
+            ret.push_back(h);
+        }
     }
     auto comp = [](const LSPInlayHint &l, const LSPInlayHint &r) {
         return l.position < r.position;
@@ -1799,6 +1804,11 @@ public:
             // for now; also no need to extract supplied token
             auto h = prepareResponse(msgid);
             h(QJsonValue());
+        } else if (method == QLatin1String("workspace/semanticTokens/refresh")) {
+            // void reply to accept, we don't handle this at the moment, but some servers send it and require some valid reply
+            // e.g. typst-lsp, see https://invent.kde.org/utilities/kate/-/issues/108
+            auto h = prepareResponse(msgid);
+            h(QJsonValue());
         } else {
             write(init_error(LSPErrorCode::MethodNotFound, method), nullptr, nullptr, &msgid);
             qCWarning(LSPCLIENT) << "discarding request" << method;
@@ -2079,3 +2089,5 @@ void LSPClientServer::workspaceSymbol(const QString &symbol, const QObject *cont
 {
     return d->workspaceSymbol(symbol, make_handler(h, context, parseWorkspaceSymbols));
 }
+
+#include "moc_lspclientserver.cpp"
