@@ -4,8 +4,7 @@
     SPDX-License-Identifier: MIT
 */
 
-#ifndef LSPCLIENTSERVER_H
-#define LSPCLIENTSERVER_H
+#pragma once
 
 #include "lspclientprotocol.h"
 
@@ -59,6 +58,7 @@ using DocumentDefinitionReplyHandler = ReplyHandler<QList<LSPLocation>>;
 using DocumentHighlightReplyHandler = ReplyHandler<QList<LSPDocumentHighlight>>;
 using DocumentHoverReplyHandler = ReplyHandler<LSPHover>;
 using DocumentCompletionReplyHandler = ReplyHandler<QList<LSPCompletionItem>>;
+using DocumentCompletionResolveReplyHandler = ReplyHandler<LSPCompletionItem>;
 using SignatureHelpReplyHandler = ReplyHandler<LSPSignatureHelp>;
 using FormattingReplyHandler = ReplyHandler<QList<LSPTextEdit>>;
 using CodeActionReplyHandler = ReplyHandler<QList<LSPCodeAction>>;
@@ -71,9 +71,14 @@ using ExpandMacroHandler = ReplyHandler<LSPExpandedMacro>;
 using SemanticTokensDeltaReplyHandler = ReplyHandler<LSPSemanticTokensDelta>;
 using WorkspaceSymbolsReplyHandler = ReplyHandler<std::vector<LSPSymbolInformation>>;
 using SelectionRangeReplyHandler = ReplyHandler<QList<std::shared_ptr<LSPSelectionRange>>>;
+using InlayHintsReplyHandler = ReplyHandler<QVector<LSPInlayHint>>;
 
 class LSPClientPlugin;
 
+struct LSPClientCapabilities {
+    bool snippetSupport = false;
+};
+
 class LSPClientServer : public QObject
 {
     Q_OBJECT
@@ -99,11 +104,27 @@ public:
     };
 
     using FoldersType = std::optional<QList<LSPWorkspaceFolder>>;
+
+    // optionally adjust server provided/suggest trigger characters
+    struct TriggerCharactersOverride {
+        QVector<QChar> exclude;
+        QVector<QChar> include;
+    };
+
+    // collect additional tweaks into a helper struct to avoid ever growing parameter list
+    // (which then also needs to be duplicated in a few places)
+    struct ExtraServerConfig {
+        FoldersType folders;
+        LSPClientCapabilities caps;
+        TriggerCharactersOverride completion;
+        TriggerCharactersOverride signature;
+    };
+
     LSPClientServer(const QStringList &server,
                     const QUrl &root,
                     const QString &langId = QString(),
                     const QJsonValue &init = QJsonValue(),
-                    const FoldersType &folders = std::nullopt);
+                    const ExtraServerConfig = {});
     ~LSPClientServer() override;
 
     // server management
@@ -133,6 +154,7 @@ public:
     RequestHandle documentHover(const QUrl &document, const LSPPosition &pos, const QObject *context, const DocumentHoverReplyHandler &h);
     RequestHandle documentReferences(const QUrl &document, const LSPPosition &pos, bool decl, const QObject *context, const DocumentDefinitionReplyHandler &h);
     RequestHandle documentCompletion(const QUrl &document, const LSPPosition &pos, const QObject *context, const DocumentCompletionReplyHandler &h);
+    RequestHandle documentCompletionResolve(const LSPCompletionItem &c, const QObject *context, const DocumentCompletionResolveReplyHandler &h);
     RequestHandle signatureHelp(const QUrl &document, const LSPPosition &pos, const QObject *context, const SignatureHelpReplyHandler &h);
     RequestHandle selectionRange(const QUrl &document, const QVector<LSPPosition> &positions, const QObject *context, const SelectionRangeReplyHandler &h);
     // clangd specific
@@ -168,6 +190,8 @@ public:
 
     RequestHandle documentSemanticTokensRange(const QUrl &document, const LSPRange &range, const QObject *context, const SemanticTokensDeltaReplyHandler &h);
 
+    RequestHandle documentInlayHint(const QUrl &document, const LSPRange &range, const QObject *context, const InlayHintsReplyHandler &h);
+
     void executeCommand(const QString &command, const QJsonValue &args);
 
     // rust-analyzer specific
@@ -200,5 +224,3 @@ private:
     // pimpl data holder
     LSPClientServerPrivate *const d;
 };
-
-#endif
