@@ -13,6 +13,7 @@
 #include <QSortFilterProxyModel>
 
 #include <KTextEditor/Document>
+#include <KTextEditor/Editor>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/View>
 
@@ -25,6 +26,7 @@
 #include <QTimer>
 #include <QTreeView>
 
+#include <drawing_utils.h>
 #include <memory>
 #include <utility>
 
@@ -217,11 +219,11 @@ class LSPClientSymbolViewImpl : public QObject, public LSPClientSymbolView
     SymbolViewProxyModel *m_identityModel;
 
     // cached icons for model
-    const QIcon m_icon_pkg = QIcon::fromTheme(QStringLiteral("code-block"));
-    const QIcon m_icon_class = QIcon::fromTheme(QStringLiteral("code-class"));
-    const QIcon m_icon_typedef = QIcon::fromTheme(QStringLiteral("code-typedef"));
-    const QIcon m_icon_function = QIcon::fromTheme(QStringLiteral("code-function"));
-    const QIcon m_icon_var = QIcon::fromTheme(QStringLiteral("code-variable"));
+    QIcon m_icon_pkg = QIcon::fromTheme(QStringLiteral("code-block"));
+    QIcon m_icon_class = QIcon::fromTheme(QStringLiteral("code-class"));
+    QIcon m_icon_typedef = QIcon::fromTheme(QStringLiteral("code-typedef"));
+    QIcon m_icon_function = QIcon::fromTheme(QStringLiteral("code-function"));
+    QIcon m_icon_var = QIcon::fromTheme(QStringLiteral("code-variable"));
 
 public:
     LSPClientSymbolViewImpl(LSPClientPlugin *plugin, KTextEditor::MainWindow *mainWin, std::shared_ptr<LSPClientServerManager> manager)
@@ -298,6 +300,12 @@ public:
         // limit cached models; will not go beyond capacity set here
         m_models.reserve(MAX_MODELS + 1);
 
+        // recolor icons
+        QObject::connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, [this](KTextEditor::Editor *e) {
+            colorIcons(e);
+        });
+        colorIcons(KTextEditor::Editor::instance());
+
         // initial trigger of symbols view update
         configUpdated();
     }
@@ -568,20 +576,42 @@ public:
         onDocumentSymbolsOrProblem(QList<LSPSymbolInformation>(), i18n("No LSP server for this document."));
     }
 
-    QStandardItem *getCurrentItem(QStandardItem *item, int line)
+    // returns (covering item, closest child of covering item after line)
+    // if distance non-null, then (output) *distance:
+    //  = irrelevant if first element of return value is non-null
+    //  < 0 if line is after item range
+    //  > 0 if line is before item range = distance from line to item range start
+    std::pair<QStandardItem *, QStandardItem *> getCurrentItem(QStandardItem *item, int line, int *distance = nullptr)
     {
         // first traverse the child items to have deepest match!
         // only do this if our stuff is expanded
+        QStandardItem *minItem = nullptr;
         if (item == m_outline->invisibleRootItem() || m_symbols->isExpanded(m_filterModel.mapFromSource(m_outline->indexFromItem(item)))) {
+            int minDistance = std::numeric_limits<int>::max();
             for (int i = 0; i < item->rowCount(); i++) {
-                if (auto citem = getCurrentItem(item->child(i), line)) {
+                int dist = 0;
+                auto child = item->child(i);
+                auto citem = getCurrentItem(child, line, &dist);
+                if (citem.first) {
                     return citem;
+                } else if (dist > 0 && dist < minDistance) {
+                    minDistance = dist;
+                    minItem = child;
                 }
             }
         }
 
         // does the line match our item?
-        return item->data(SymbolViewRoles::SymbolRange).value<KTextEditor::Range>().overlapsLine(line) ? item : nullptr;
+        auto range = item->data(SymbolViewRoles::SymbolRange).value<KTextEditor::Range>();
+        if (range.overlapsLine(line)) {
+            return {item, minItem};
+        } else {
+            if (distance) {
+                auto startline = range.start().line();
+                *distance = line < startline ? startline - line : -1;
+            }
+            return {nullptr, minItem};
+        }
     }
 
     void updateCurrentTreeItem()
@@ -594,17 +624,24 @@ public:
         /**
          * get item if any
          */
-        QStandardItem *item = getCurrentItem(m_outline->invisibleRootItem(), editView->cursorPositionVirtual().line());
-        if (!item) {
+        auto items = getCurrentItem(m_outline->invisibleRootItem(), editView->cursorPositionVirtual().line());
+        if (!items.first) {
             return;
         }
 
         /**
-         * select it
+         * select it;
+         * however, in a typical (e.g. class/namespace) case, the areas between (e.g. method) children
+         * select the parent (class) as item.  To aid navigation in such case, the closest (following)
+         * child is also considered (as the parent item may in fact be quite far away in the symbol tree).
          */
-        QModelIndex index = m_filterModel.mapFromSource(m_outline->indexFromItem(item));
-        m_symbols->scrollTo(index);
-        m_symbols->selectionModel()->setCurrentIndex(index, QItemSelectionModel::Clear | QItemSelectionModel::Select);
+        QModelIndex coverIndex = m_filterModel.mapFromSource(m_outline->indexFromItem(items.first));
+        QModelIndex closestIndex = m_filterModel.mapFromSource(m_outline->indexFromItem(items.second ? items.second : items.first));
+        // select covering (parent) item
+        m_symbols->selectionModel()->setCurrentIndex(coverIndex, QItemSelectionModel::Clear | QItemSelectionModel::Select);
+        // add child to selection and move view there
+        m_symbols->selectionModel()->setCurrentIndex(closestIndex, QItemSelectionModel::Select);
+        m_symbols->scrollTo(closestIndex);
     }
 
     void goToSymbol(const QModelIndex &index)
@@ -621,6 +658,27 @@ public:
         return m_identityModel;
     }
 
+private:
+    void colorIcons(KTextEditor::Editor *e)
+    {
+        using KSyntaxHighlighting::Theme;
+        auto theme = e->theme();
+        auto varColor = QColor::fromRgba(theme.textColor(Theme::Variable));
+        m_icon_var = Utils::colorIcon(m_icon_var, varColor);
+
+        auto typeColor = QColor::fromRgba(theme.textColor(Theme::DataType));
+        m_icon_class = Utils::colorIcon(m_icon_class, typeColor);
+
+        auto enColor = QColor::fromRgba(theme.textColor(Theme::Constant));
+        m_icon_typedef = Utils::colorIcon(m_icon_typedef, enColor);
+
+        auto funcColor = QColor::fromRgba(theme.textColor(Theme::Function));
+        m_icon_function = Utils::colorIcon(m_icon_function, funcColor);
+
+        auto blockColor = QColor::fromRgba(theme.textColor(Theme::Import));
+        m_icon_pkg = Utils::colorIcon(m_icon_pkg, blockColor);
+    }
+
 private Q_SLOTS:
     /**
      * React on filter change
@@ -654,3 +712,4 @@ LSPClientSymbolView *LSPClientSymbolView::new_(LSPClientPlugin *plugin, KTextEdi
 LSPClientSymbolView::~LSPClientSymbolView() = default;
 
 #include "lspclientsymbolview.moc"
+#include "moc_lspclientsymbolview.cpp"
