@@ -6,6 +6,7 @@
 
 #include "comparebranchesview.h"
 #include "diffparams.h"
+#include "kateprojectitem.h"
 #include "kateprojectpluginview.h"
 #include "kateprojectworker.h"
 #include "ktexteditor_utils.h"
@@ -178,3 +179,5 @@ void CompareBranchesView::showDiff(const QModelIndex &idx)
     d.arguments = git.arguments();
     Utils::showDiff(git.readAllStandardOutput(), d, m_pluginView->mainWindow());
 }
+
+#include "moc_comparebranchesview.cpp"
