@@ -57,11 +57,6 @@ public:
     void runCmdInTerminal(const QString &workingDir, const QString &cmd);
 
 private:
-    /**
-     * our plugin view
-     */
-    KateProjectPluginView *m_pluginView;
-
     /**
      * our project
      */
