@@ -53,7 +53,12 @@ KPluginFactory *KateProjectInfoViewTerminal::pluginFactory()
     if (s_pluginFactory) {
         return s_pluginFactory;
     }
-    return s_pluginFactory = KPluginFactory::loadFactory(QStringLiteral("konsolepart")).plugin;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const QString konsolePart = QStringLiteral("konsolepart");
+#else
+    const QString konsolePart = QStringLiteral("kf6/parts/konsolepart");
+#endif
+    return s_pluginFactory = KPluginFactory::loadFactory(konsolePart).plugin;
 }
 
 void KateProjectInfoViewTerminal::showEvent(QShowEvent *)
@@ -142,13 +147,21 @@ static const QStringList s_escapeExceptions{QStringLiteral("vi"), QStringLiteral
 
 bool KateProjectInfoViewTerminal::ignoreEsc() const
 {
-    if (!m_konsolePart || !KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyBehaviour", true)) {
+    // if konsole is not found, do not ignore esc
+    if (!m_konsolePart && !KConfigGroup(KSharedConfig::openConfig(), "Konsole").exists()) {
         return false;
     }
 
-    const QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
-    const auto app = qobject_cast<TerminalInterface *>(m_konsolePart)->foregroundProcessName();
-    return exceptList.contains(app);
+    // If Hide with Esc is disabled in konsole settings, ignore esc press.
+    if (!KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyBehaviour", true)) {
+        return true;
+    }
+    // Otherwise only ignore apps in given list
+    else {
+        const QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
+        const auto app = qobject_cast<TerminalInterface *>(m_konsolePart)->foregroundProcessName();
+        return exceptList.contains(app);
+    }
 }
 
 bool KateProjectInfoViewTerminal::isLoadable()
@@ -209,3 +222,5 @@ void KateProjectInfoViewTerminal::runCommand(const QString &workingDir, const QS
     terminal->sendInput(changeDirCmd);
     terminal->sendInput(cmd.trimmed() + QStringLiteral("\n"));
 }
+
+#include "moc_kateprojectinfoviewterminal.cpp"
