@@ -133,9 +133,6 @@ public:
     bool multiProjectCompletion() const;
     bool multiProjectGoto() const;
 
-    void setGitStatusShowNumStat(bool show);
-    bool showGitStatusWithNumStat() const;
-
     void setSingleClickAction(ClickAction cb);
     ClickAction singleClickAcion();
 
@@ -199,13 +196,6 @@ Q_SIGNALS:
      */
     void configUpdated();
 
-    /**
-     * Signal emitted to tell the views to activate some project.
-     * Used for loading projects from the command line.
-     * @param project project to activate in the views
-     */
-    void activateProject(KateProject *project);
-
 public Q_SLOTS:
     /**
      * New document got created, we need to update our connections
@@ -285,7 +275,6 @@ private:
     bool m_multiProjectGoto = false;
 
     // git features
-    bool m_gitNumStat = true;
     ClickAction m_singleClickAction = ClickAction::ShowDiff;
     ClickAction m_doubleClickAction = ClickAction::StageUnstage;
 
