@@ -5,8 +5,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KATE_PROJECT_VIEW_TREE_H
-#define KATE_PROJECT_VIEW_TREE_H
+#pragma once
 
 #include <QTreeView>
 
@@ -104,5 +103,3 @@ private:
      */
     KateProject *m_project;
 };
-
-#endif
