@@ -3,8 +3,7 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef PUSHPULLDIALOG_H
-#define PUSHPULLDIALOG_H
+#pragma once
 
 #include "quickdialog.h"
 
@@ -20,8 +19,8 @@ public:
     Q_SIGNAL void runGitCommand(const QStringList &args);
 
 private:
-    QString buildPushString();
-    QString buildPullString();
+    void detectGerrit();
+    QStringList buildCmdStrings(Mode m);
     void loadLastExecutedCommands();
     void saveCommand(const QString &command);
 
@@ -32,6 +31,8 @@ private:
 
 protected Q_SLOTS:
     void slotReturnPressed(const QModelIndex &index) override;
-};
 
-#endif // PUSHPULLDIALOG_H
+private:
+    bool m_isGerrit = false;
+    QString m_gerritBranch;
+};
