@@ -5,8 +5,7 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef KATE_PROJECT_CODE_ANALYSIS_TOOL_CPPCHECK_H
-#define KATE_PROJECT_CODE_ANALYSIS_TOOL_CPPCHECK_H
+#pragma once
 
 #include "../kateprojectcodeanalysistool.h"
 
@@ -34,9 +33,7 @@ public:
 
     QString notInstalledMessage() const override;
 
-    QStringList parseLine(const QString &line) const override;
+    FileDiagnostics parseLine(const QString &line) const override;
 
     QString stdinMessages() override;
 };
-
-#endif // KATE_PROJECT_CODE_ANALYSIS_TOOL_CPPCHECK_H
