@@ -120,7 +120,11 @@ private Q_SLOTS:
 
     void matchesFound(const QUrl &url, const QVector<KateSearchMatch> &searchMatches, KTextEditor::Document *doc);
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void addRangeAndMark(KTextEditor::Document *doc, const KateSearchMatch &match, KTextEditor::Attribute::Ptr attr);
+#else
     void addRangeAndMark(KTextEditor::Document *doc, const KateSearchMatch &match, KTextEditor::Attribute::Ptr attr, KTextEditor::MovingInterface *miface);
+#endif
 
     void searchDone();
     void searchWhileTypingDone();
@@ -197,8 +201,6 @@ private:
 
     QTimer m_diskSearchDoneTimer;
     QTimer m_updateCheckedStateTimer;
-    QAction *m_matchCase = nullptr;
-    QAction *m_useRegExp = nullptr;
     Results *m_curResults = nullptr;
     QTabBar *m_tabBar = nullptr;
     bool m_searchJustOpened = false;
