@@ -25,7 +25,9 @@
 #include "pseudo_dtd.h"
 
 #include <ktexteditor/application.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <ktexteditor/codecompletioninterface.h>
+#endif
 #include <ktexteditor/codecompletionmodel.h>
 #include <ktexteditor/codecompletionmodelcontrollerinterface.h>
 #include <ktexteditor/document.h>
@@ -127,7 +129,9 @@ protected:
     int m_correctPos;
 
     // code completion stuff:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KTextEditor::CodeCompletionInterface *m_codeInterface = nullptr;
+#endif
 
     /// maps KTE::Document -> DTD
     QHash<KTextEditor::Document *, PseudoDTD *> m_docDtds;
