@@ -2,8 +2,7 @@
     SPDX-FileCopyrightText: 2022 Waqar Ahmed <waqar.17a@gmail.com>
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef DIFF_LINE_NUM_AREA
-#define DIFF_LINE_NUM_AREA
+#pragma once
 
 #include <QWidget>
 
@@ -22,6 +21,16 @@ public:
         maxLineNum = n;
     }
 
+    int lineNumForBlock(int block)
+    {
+        return m_lineToNumA.value(block);
+    }
+
+    int blockForLineNum(int lineNo)
+    {
+        return m_lineToNumA.indexOf(lineNo);
+    }
+
 protected:
     void paintEvent(QPaintEvent *event) override;
     void mousePressEvent(QMouseEvent *e) override;
@@ -38,5 +47,3 @@ private:
     QVector<int> m_lineToNumB;
     int maxLineNum = 0;
 };
-
-#endif
