@@ -5,14 +5,17 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef __KATE_APP_H__
-#define __KATE_APP_H__
+#pragma once
 
 #include <ktexteditor/application.h>
 
 #ifdef WITH_KUSERFEEDBACK
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/Provider>
 #endif
+#endif
 
 #include "kateappadaptor.h"
 #include "katedocmanager.h"
@@ -46,6 +49,17 @@ class KATE_PRIVATE_EXPORT KateApp : public QObject
      * constructors & accessor to app object + plugin interface for it
      */
 public:
+    /**
+     * Do the needed setup steps before we create our QApplication.
+     * @param detach shall we detach from the terminal?
+     */
+    static void initPreApplicationCreation(bool detach);
+
+    /**
+     * Was the application started inside a terminal?
+     */
+    static bool isInsideTerminal();
+
     /**
      *  Are we full featured Kate or the simplified KWrite?
      */
@@ -186,9 +200,10 @@ public:
      * create a new main window, use given config if any for restore
      * @param sconfig session config object
      * @param sgroup session group for this window
+     * @param userTriggered did the user trigger creation of this new window
      * @return new constructed main window
      */
-    static KateMainWindow *newMainWindow(KConfig *sconfig = nullptr, const QString &sgroup = QString());
+    static KateMainWindow *newMainWindow(KConfig *sconfig = nullptr, const QString &sgroup = QString(), bool userTriggered = false);
 
     /**
      * add the mainwindow given
@@ -490,5 +505,3 @@ private:
     KUserFeedback::Provider m_userFeedbackProvider;
 #endif
 };
-
-#endif
