@@ -58,6 +58,7 @@ KateConfigDialog::KateConfigDialog(KateMainWindow *parent)
     setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
 
     m_searchLineEdit->setPlaceholderText(i18n("Search..."));
+    m_searchLineEdit->setClearButtonEnabled(true);
     setFocusProxy(m_searchLineEdit);
     m_searchTimer->setSingleShot(true);
     m_searchTimer->setInterval(400);
@@ -78,8 +79,7 @@ KateConfigDialog::KateConfigDialog(KateMainWindow *parent)
 #else
         setFaceType(KPageDialog::List);
 #endif
-    }
-    else {
+    } else {
         setFaceType(KPageDialog::List);
     }
 
@@ -498,6 +498,12 @@ void KateConfigDialog::addBehaviorPage()
     connect(m_tabsElided, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
     vbox->addWidget(m_tabsElided);
 
+    m_openNewTabInFrontOfCurrent = new QCheckBox(i18n("Open new tab to the right of current tab."), this);
+    m_openNewTabInFrontOfCurrent->setChecked(cgGeneral.readEntry("Open New Tab To The Right Of Current", false));
+    m_openNewTabInFrontOfCurrent->setToolTip(i18n("If unchecked the new tab will open at the end."));
+    connect(m_openNewTabInFrontOfCurrent, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
+    vbox->addWidget(m_openNewTabInFrontOfCurrent);
+
     layout->addWidget(buttonGroup);
 
     buttonGroup = new QGroupBox(i18n("&Mouse"), generalFrame);
@@ -814,6 +820,7 @@ void KateConfigDialog::slotApply()
 
         cg.writeEntry("Allow Tab Scrolling", m_tabsScrollable->isChecked());
         cg.writeEntry("Elide Tab Text", m_tabsElided->isChecked());
+        cg.writeEntry("Open New Tab To The Right Of Current", m_openNewTabInFrontOfCurrent->isChecked());
 
         cg.writeEntry("Diff Show Style", m_diffStyle->currentIndex());
 
@@ -822,9 +829,13 @@ void KateConfigDialog::slotApply()
         // patch document modified warn state
         const QList<KTextEditor::Document *> &docs = KateApp::self()->documentManager()->documentList();
         for (KTextEditor::Document *doc : docs) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            doc->setModifiedOnDiskWarning(!m_modNotifications->isChecked());
+#else
             if (auto modIface = qobject_cast<KTextEditor::ModificationInterface *>(doc)) {
                 modIface->setModifiedOnDiskWarning(!m_modNotifications->isChecked());
             }
+#endif
         }
 
         m_mainWindow->saveOptions();
@@ -950,3 +961,5 @@ KPageWidgetItem *KateConfigDialog::addScrollablePage(QWidget *page, const QStrin
     boxLayout->addWidget(scroll);
     return addPage(frame, itemName);
 }
+
+#include "moc_kateconfigdialog.cpp"
