@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: LGPL-2.0-or-later
  **/
 
-#ifndef KATE_FILEACTIONS_H
-#define KATE_FILEACTIONS_H
+#pragma once
 
 #include "kateprivate_export.h"
 
@@ -15,7 +14,10 @@
 
 #include <QString>
 
+class QAction;
+class QMenu;
 class QWidget;
+class QUrl;
 namespace KTextEditor
 {
 class Document;
@@ -27,12 +29,12 @@ namespace KateFileActions
  * Copies the file path to clipboard.
  * If the document has no file, the clipboard will be emptied.
  */
-void copyFilePathToClipboard(KTextEditor::Document *document);
+KATE_PRIVATE_EXPORT void copyFilePathToClipboard(KTextEditor::Document *document);
 
 /**
  * Tries to open and highlight the underlying url in the filemanager
  */
-void openContainingFolder(KTextEditor::Document *document);
+KATE_PRIVATE_EXPORT void openContainingFolder(KTextEditor::Document *document);
 
 /**
  * Shows a Rename dialog to rename the file associated with the document.
@@ -42,7 +44,7 @@ void openContainingFolder(KTextEditor::Document *document);
  */
 KATE_PRIVATE_EXPORT void renameDocumentFile(QWidget *parent, KTextEditor::Document *document);
 
-void openFilePropertiesDialog(QWidget *parent, KTextEditor::Document *document);
+KATE_PRIVATE_EXPORT void openFilePropertiesDialog(QWidget *parent, KTextEditor::Document *document);
 
 /**
  * Asks the user if the file should really be deleted. If yes, the file
@@ -50,7 +52,7 @@ void openFilePropertiesDialog(QWidget *parent, KTextEditor::Document *document);
  *
  * Nothing is done if the document is nullptr or has no associated file.
  */
-void deleteDocumentFile(QWidget *parent, KTextEditor::Document *document);
+KATE_PRIVATE_EXPORT void deleteDocumentFile(QWidget *parent, KTextEditor::Document *document);
 
 /**
  * @returns a list of supported diff tools (names of the executables + paths to them, empty if not found in PATH)
@@ -74,6 +76,14 @@ QVector<std::pair<QString, QString>> supportedDiffTools();
  * IDEA for later: compare with unsaved buffer data instead of underlying file
  */
 bool compareWithExternalProgram(KTextEditor::Document *documentA, KTextEditor::Document *documentB, const QString &diffExecutable);
-}
 
-#endif
+/**
+ * Prepares the open with menu
+ */
+KATE_PRIVATE_EXPORT void prepareOpenWithMenu(const QUrl &url, QMenu *menu);
+
+/**
+ * Prepares the open with menu
+ */
+KATE_PRIVATE_EXPORT void showOpenWithMenu(QWidget *parent, const QUrl &url, QAction *action);
+}
