@@ -316,7 +316,7 @@ void KateMainWindow::setupMainWindow(KConfig *sconfig)
                                       KTextEditor::MainWindow::Bottom,
                                       QIcon::fromTheme(QStringLiteral("output_win")),
                                       i18n("Output"));
-    m_outputView = new KateOutputView(this, m_toolViewOutput, toolviewToggleButton(static_cast<KateMDI::ToolView *>(m_toolViewOutput)));
+    m_outputView = new KateOutputView(this, m_toolViewOutput);
 
     m_diagView = DiagnosticsView::instance(wrapper());
     m_diagView->readSessionConfig(KConfigGroup(sconfig, "Kate Diagnostics"));
@@ -606,6 +606,9 @@ void KateMainWindow::slotDocumentCloseOther()
 
 bool KateMainWindow::queryClose_internal(KTextEditor::Document *doc, KateMainWindow *win)
 {
+    // we want no auto saving during windows closing, we handle that explicitly
+    KateSessionManager::AutoSaveBlocker blocker(KateApp::self()->sessionManager());
+
     const auto documentCount = KateApp::self()->documentManager()->documentList().size();
 
     if (!showModOnDiskPrompt(PromptEdited)) {
@@ -670,6 +673,9 @@ bool KateMainWindow::queryClose_internal(KTextEditor::Document *doc, KateMainWin
  */
 bool KateMainWindow::queryClose()
 {
+    // we want no auto saving during windows closing, we handle that explicitly
+    KateSessionManager::AutoSaveBlocker blocker(KateApp::self()->sessionManager());
+
     // session saving, can we close all views ?
     // just test, not close them actually
     if (qApp->isSavingSession()) {
@@ -1521,15 +1527,6 @@ bool KateMainWindow::hideToolView(QWidget *widget)
     return KateMDI::MainWindow::hideToolView(qobject_cast<KateMDI::ToolView *>(widget));
 }
 
-QWidget *KateMainWindow::tabForToolView(QWidget *widget)
-{
-    if (!qobject_cast<KateMDI::ToolView *>(widget)) {
-        return nullptr;
-    }
-
-    return KateMDI::MainWindow::toolviewToggleButton(static_cast<KateMDI::ToolView *>(widget));
-}
-
 void KateMainWindow::addRecentOpenedFile(const QUrl &url)
 {
     // skip non-existing urls for untitled documents
