@@ -620,6 +620,17 @@ void Sidebar::appendStyledTab(int id, MultiTabBar *bar, ToolView *widget)
 
     // fixup styling
     updateButtonStyle(newTab);
+
+    // tell that we have a new tab, useful for e.g. overlays
+    // do it delayed so that if toolview was constructed before the container widget
+    // and the container wants to react to this signal, it can do so. Otherwise, this
+    // will fire before the container has connected to this signal
+    QMetaObject::invokeMethod(
+        m_mainWin,
+        [w = m_mainWin, widget, newTab] {
+            Q_EMIT w->tabForToolViewAdded(widget, newTab);
+        },
+        Qt::QueuedConnection);
 }
 
 void Sidebar::updateButtonStyle(KMultiTabBarTab *button)
@@ -1524,14 +1535,6 @@ bool MainWindow::hideToolView(ToolView *widget)
     return ret;
 }
 
-QWidget *MainWindow::toolviewToggleButton(ToolView *tv)
-{
-    if (tv && tv->sidebar()) {
-        return tv->sidebar()->tabButtonForToolview(tv);
-    }
-    return nullptr;
-}
-
 void MainWindow::hideToolViews()
 {
     for (const auto &tv : m_toolviews) {
