@@ -9,7 +9,9 @@
 #pragma once
 
 #include <ktexteditor/document.h>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <ktexteditor/modificationinterface.h>
+#endif
 #include <ktexteditor/view.h>
 
 #include "doc_or_widget.h"
@@ -357,4 +359,7 @@ private:
 
     // should the tab bar be auto hidden if just one document is open?
     bool m_autoHideTabBar = false;
+
+    // Block adding position to history if this is true
+    bool m_blockAddHistory = false;
 };
