@@ -50,6 +50,23 @@ KateSessionManager::KateSessionManager(QObject *parent, const QString &sessionsD
 
     // initial creation of the session list from disk files
     updateSessionList();
+
+    // init the session auto save
+    m_sessionSaveTimer.setInterval(5000);
+    m_sessionSaveTimer.setSingleShot(true);
+    auto startTimer = [this] {
+        if (m_sessionSaveTimerBlocked == 0 && !m_sessionSaveTimer.isActive()) {
+            m_sessionSaveTimer.start();
+        }
+    };
+    auto dm = KateApp::self()->documentManager();
+    connect(dm, &KateDocManager::documentCreated, &m_sessionSaveTimer, startTimer);
+    connect(dm, &KateDocManager::documentDeleted, &m_sessionSaveTimer, startTimer);
+    m_sessionSaveTimer.callOnTimeout(this, [this] {
+        if (m_sessionSaveTimerBlocked == 0) {
+            saveActiveSession(true);
+        }
+    });
 }
 
 KateSessionManager::~KateSessionManager() = default;
@@ -102,8 +119,8 @@ bool KateSessionManager::activateSession(KateSession::Ptr session, const bool cl
         return true;
     }
 
-    // delete the timer
-    m_sessionSaveTimer.reset();
+    // we want no auto saving during session switches
+    AutoSaveBlocker blocker(this);
 
     if (!session->isAnonymous()) {
         // check if the requested session is already open in another instance
@@ -172,9 +189,6 @@ bool KateSessionManager::activateSession(KateSession::Ptr session, const bool cl
     }
 
     Q_EMIT sessionChanged();
-
-    // Initialize the session save timer
-    initTimer();
     return true;
 }
 
@@ -697,29 +711,6 @@ bool KateSessionManager::isViewLessDocumentViewSpaceGroup(const QString &group)
     return false;
 }
 
-void KateSessionManager::initTimer()
-{
-    if (m_sessionSaveTimer) {
-        qWarning() << "Session save timer is already initalized! should not happen";
-        return;
-    }
-    m_sessionSaveTimer = std::make_unique<QTimer>();
-    m_sessionSaveTimer->setInterval(5000);
-    m_sessionSaveTimer->setSingleShot(true);
-    auto *t = m_sessionSaveTimer.get();
-    auto dm = KateApp::self()->documentManager();
-    auto startTimer = [t] {
-        if (!t->isActive()) {
-            t->start();
-        }
-    };
-    connect(dm, &KateDocManager::documentCreated, t, startTimer);
-    connect(dm, &KateDocManager::documentDeleted, t, startTimer);
-    m_sessionSaveTimer->callOnTimeout(this, [this] {
-        saveActiveSession(true);
-    });
-}
-
 // END KateSessionManager
 
 #include "moc_katesessionmanager.cpp"
